"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MongoConnector = void 0;
const mongodb_1 = require("mongodb");
class MongoConnector {
    constructor(url, dbName) {
        this.url = url;
        this.dbName = dbName;
    }
    async connect(started, options = {
        useNewUrlParser: true,
        useUnifiedTopology: true,
    }) {
        try {
            this.client = await mongodb_1.MongoClient.connect(this.url, options);
            this.db = await this.client.db(this.dbName);
            if (started) {
                started();
            }
        }
        catch (ex) {
            console.log(`Connection Error to ${this.url} / ${this.dbName}: ${ex.message}`);
            throw new Error(`Connection Error to ${this.url}/${this.dbName}`);
        }
    }
    async disconnect() {
        await this.client.close();
    }
    async dispose() {
        console.log(this.client.close);
        await this.db.dropDatabase();
        await this.client.close();
    }
    collection(name) {
        return this.db.collection(name);
    }
}
exports.MongoConnector = MongoConnector;
exports.default = MongoConnector;
