"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const proxyquire = require("proxyquire");
const assert = require("power-assert");
const sinon = require("sinon");
const dbStub = sinon.stub();
const MongoStub = {
    MongoClient: {
        connect: () => ({
            db: dbStub,
            close: sinon.stub(),
        }),
    },
};
const MongoConnectorStub = proxyquire("../mongo_connector", {
    mongodb: MongoStub,
}).MongoConnector;
describe("connector", () => {
    it("will initialise url", async () => {
        const url = "mongodb://url";
        dbStub.reset();
        const connector = new MongoConnectorStub(url, "clara");
        await connector.connect();
        assert.equal(connector.url, url);
        assert(dbStub.calledOnce);
    });
    it("will initialise and calls back", async () => {
        const url = "mongodb://url";
        const db = {};
        const startedSpy = sinon.spy();
        dbStub.returns(db);
        const connector = new MongoConnectorStub(url, "clara");
        await connector.connect(startedSpy);
        assert.equal(connector.db, db);
        assert(startedSpy.calledOnce);
    });
    it("will create a new collection", async () => {
        const url = "";
        const db = {
            collection: sinon.spy(),
        };
        dbStub.returns(db);
        const connector = new MongoConnectorStub(url, "clara");
        await connector.connect();
        assert.equal(connector.db, db);
        const collectionName = "Col";
        const col = connector.collection(collectionName);
        assert(db.collection.calledWith(collectionName));
    });
    it("can dispose database", async () => {
        const connector = new MongoConnectorStub(null, "clara");
        const db = {
            dropDatabase: sinon.stub(),
        };
        dbStub.returns(db);
        await connector.connect();
        await connector.dispose();
        sinon.assert.calledOnce(connector.db.dropDatabase);
        sinon.assert.calledOnce(connector.client.close);
    });
});
